[![check](https://github.com/retospect/wibble/actions/workflows/check.yml/badge.svg)](https://github.com/retospect/wibble/actions/workflows/check.yml)
# Wibble - a template for simple python packages


A minimalist template for a python package.

Provides the bl and the blarg commands, 
and does basic continuous integraton testing on github.

Make a copy of the project, and fix the replacements below.

## Things to replace

- ```grep -ri word .``` will find the *word* in all the files
- ```find . | grep word``` will find the *word* in any filenames
- *retospect* - changed to your github user name
- *wibble* - change to the name of your project
- *wobble* - change to the internal package name you want to use 
- *fafa* - change to whatever your commandline command should be if you are providing a script
- update the pyproject.py file to have your name and the right description. 
